pub enum TraceTxVersionedOutputPayload {
V1(TraceTxOutputPayloadV1),
V2(TraceTxOutputPayloadV2),
}Expand description
The output type returned when calling the trace_tx_versioned runtime API function. This
function replaces the unversioned trace_tx runtime API function.
Variants
V1(TraceTxOutputPayloadV1)
The output returned when calling the trace_tx_versioned runtime API function with V1
arguments.
This output is identical to the output returned by the unversioned trace_tx runtime API
function.
V2(TraceTxOutputPayloadV2)
This version uses TraceV2 for trace output instead of TraceV1.
TraceV2::Call uses CallTraceV2, which replaces CallLogV1 with CallLogV2.
CallLogV2 adds index, the block-wide log index matching the receipt logIndex, while
position continues to describe log ordering relative to child calls within the same trace
frame. CallTraceV2 also removes child_call_count, which was only used to calculate
position. Prestate and execution traces are unchanged.